@@ -1,5 +1,5 @@
 package Selenium::ActionChains;
-$Selenium::ActionChains::VERSION = '0.2550'; # TRIAL
+$Selenium::ActionChains::VERSION = '0.2650'; # TRIAL
 # ABSTRACT: Action chains for Selenium::Remote::Driver
 use Moo;
 
@@ -165,7 +165,7 @@ Selenium::ActionChains - Action chains for Selenium::Remote::Driver
 
 =head1 VERSION
 
-version 0.2550
+version 0.2650
 
 =head1 SYNOPSIS
 
@@ -413,15 +413,23 @@ feature.
 
 =head1 AUTHORS
 
+Current Maintainers:
+
 =over 4
 
 =item *
 
-Aditya Ivaturi <ivaturi@gmail.com>
+Daniel Gempesaw <gempesaw@gmail.com>
 
 =item *
 
-Daniel Gempesaw <gempesaw@gmail.com>
+Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
+
+=back
+
+Previous maintainers:
+
+=over 4
 
 =item *
 
@@ -433,11 +441,21 @@ Mark Stosberg <mark@stosberg.com>
 
 =back
 
+Original authors:
+
+=over 4
+
+=item *
+
+Aditya Ivaturi <ivaturi@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014 Daniel Gempesaw
+Copyright (c) 2014-2015 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
