@@ -1,5 +1,5 @@
 package Selenium::PhantomJS;
-$Selenium::PhantomJS::VERSION = '0.2550'; # TRIAL
+$Selenium::PhantomJS::VERSION = '0.2650'; # TRIAL
 # ABSTRACT: Use GhostDriver without a Selenium server
 use Moo;
 use Selenium::CanStartBinary::FindBinary qw/coerce_simple_binary/;
@@ -36,6 +36,7 @@ has '_binary_args' => (
 
 with 'Selenium::CanStartBinary';
 
+
 1;
 
 __END__
@@ -50,7 +51,7 @@ Selenium::PhantomJS - Use GhostDriver without a Selenium server
 
 =head1 VERSION
 
-version 0.2550
+version 0.2650
 
 =head1 SYNOPSIS
 
@@ -107,6 +108,17 @@ See L<Selenium::CanStartBinary/port> for more details, and
 L<Selenium::Remote::Driver/port> after instantiation to see what the
 actual port turned out to be.
 
+=head2 startup_timeout
+
+Optional: specify how long to wait for the binary to start itself and
+listen on its port. The default duration is arbitrarily 10 seconds. It
+accepts an integer number of seconds to wait: the following will wait
+up to 20 seconds:
+
+    Selenium::PhantomJS->new( startup_timeout => 20 );
+
+See L<Selenium::CanStartBinary/startup_timeout> for more information.
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
@@ -130,15 +142,23 @@ feature.
 
 =head1 AUTHORS
 
+Current Maintainers:
+
 =over 4
 
 =item *
 
-Aditya Ivaturi <ivaturi@gmail.com>
+Daniel Gempesaw <gempesaw@gmail.com>
 
 =item *
 
-Daniel Gempesaw <gempesaw@gmail.com>
+Emmanuel Peroumalnaïk <peroumalnaik.emmanuel@gmail.com>
+
+=back
+
+Previous maintainers:
+
+=over 4
 
 =item *
 
@@ -150,11 +170,21 @@ Mark Stosberg <mark@stosberg.com>
 
 =back
 
+Original authors:
+
+=over 4
+
+=item *
+
+Aditya Ivaturi <ivaturi@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (c) 2010-2011 Aditya Ivaturi, Gordon Child
 
-Copyright (c) 2014 Daniel Gempesaw
+Copyright (c) 2014-2015 Daniel Gempesaw
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
